rpl\_pack.flag.Brine
====================

.. currentmodule:: rpl_pack.flag

.. autoclass:: Brine
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __call__, __add__, __mul__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Brine.density_brine
      ~Brine.density_water
      ~Brine.density_water_CO2
      ~Brine.modulus_brine
      ~Brine.modulus_water
      ~Brine.resistivity_brine
      ~Brine.saturated_vapor_pressure
      ~Brine.saturated_vapor_temperature
      ~Brine.solubility_gas_brine
      ~Brine.solubility_gas_water
      ~Brine.velocity_brine
      ~Brine.velocity_water
      ~Brine.velocity_water_CO2
      ~Brine.viscosity_brine
      ~Brine.viscosity_water
   
   

   
   
   